import { IMap } from './map';
import { Comparer, ISortedCollection } from './sortedcollection';
export declare type Key = string | number;
export interface IKeyWithOrder<K, O> {
    key: K;
    order: O;
}
export interface ISortedMap<K, V, O = any> {
    map: IMap<K, V>;
    sortedCollection: ISortedCollection<IKeyWithOrder<K, O>>;
}
export declare type GetOrderingKey<V, O> = (value: V) => O;
export declare class SortedMapAdapter<K extends Key, V, O = any> {
    private getOrderingKey;
    private mapAdapter;
    private sortedCollectionAdapter;
    constructor(args: {
        getOrderingKey: GetOrderingKey<V, O>;
        orderComparer?: Comparer<O>;
    });
    create(): ISortedMap<K, V, O>;
    get(sortedMap: ISortedMap<K, V, O>, key: K): V | undefined;
    getIterable(sortedMap: ISortedMap<K, V, O>): Iterable<{
        key: K;
        value: V;
    }>;
    getValuesIterable(sortedMap: ISortedMap<K, V, O>): Iterable<V>;
    set(sortedMap: ISortedMap<K, V, O>, key: K, value: V): void;
    remove(sortedMap: ISortedMap<K, V, O>, key: K): void;
    update(sortedMap: ISortedMap<K, V, O>, key: K, updater: (item: V) => V | void): void | V;
    getSize(sortedMap: ISortedMap<K, V, O>): number;
    getFirst(sortedMap: ISortedMap<K, V, O>): V | undefined;
    getLast(sortedMap: ISortedMap<K, V, O>): V | undefined;
}
